@@ -19,9 +19,13 @@ logAlpha <- function(m)
 {
     data <- m$data
     nbStates <- ncol(m$mle$stepPar)
+    nbAnimals <- length(unique(data$ID))
     nbObs <- nrow(data)
     lalpha <- matrix(NA,nbObs,nbStates)
 
+    beta <- m$mle$beta
+    delta <- m$mle$delta
+
     covsCol <- which(names(data)!="ID" & names(data)!="x" & names(data)!="y" &
                          names(data)!="step" & names(data)!="angle")
     covs <- data[,covsCol]
@@ -30,17 +34,24 @@ logAlpha <- function(m)
                       m$mle$anglePar,m$conditions$zeroInflation,m$knownStates)
 
     if(nbStates>1)
-        trMat <- trMatrix_rcpp(nbStates,m$mle$beta,as.matrix(covs))
+        trMat <- trMatrix_rcpp(nbStates,beta,as.matrix(covs))
     else
         trMat <- array(1,dim=c(1,1,nbObs))
 
-    lscale <- 0
-    foo <- m$mle$delta*probs[1,]
-    lalpha[1,] <- log(foo)+lscale
+    aInd <- NULL
+    for(i in 1:nbAnimals)
+        aInd <- c(aInd,which(data$ID==unique(data$ID)[i])[1])
 
-    for(i in 2:nbObs) {
+    k <- 1
+    for(i in 1:nbObs) {
         gamma <- trMat[,,i]
-        foo <- foo%*%gamma*probs[i,]
+        if(any(i==aInd)){
+            k <- max(nbAnimals,k+1)
+            foo <- delta*probs[i,]
+            lscale <- 0
+        } else {
+            foo <- (foo %*% gamma)*probs[i,]
+        }
         lscale <- lscale+log(sum(foo))
         foo <- foo/sum(foo)
         lalpha[i,] <- log(foo)+lscale
